================
API - LCD Module
================

.. module:: lannerpsp.sdk_lcm

.. currentmodule:: lannerpsp

Regular Classes
===============

The following classes are intended for general use with the devices they
represent. All classes in this section are concrete (not abstract).

LCM
---

.. autoclass:: LCM
    :members: search_port, reset, set_backlight, set_cursor, write, clear,
        get_keys_status, exec_callback

Supported Platforms
===================

The following platforms have been verified and confirmed to be supported:

* `NCA-2510`_

.. _NCA-2510: https://lannerinc.com/products/telecom-datacenter-appliances/vcpe-ucpe-platforms/nca-2510
